=====
Array
=====

The following methods are available under the `expr.arr` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.arr.max
    Expr.arr.min
    Expr.arr.median
    Expr.arr.sum
    Expr.arr.std
    Expr.arr.to_list
    Expr.arr.unique
    Expr.arr.n_unique
    Expr.arr.var
    Expr.arr.all
    Expr.arr.any
    Expr.arr.sort
    Expr.arr.reverse
    Expr.arr.arg_min
    Expr.arr.arg_max
    Expr.arr.get
    Expr.arr.first
    Expr.arr.last
    Expr.arr.join
    Expr.arr.explode
    Expr.arr.contains
    Expr.arr.count_matches
    Expr.arr.to_struct
    Expr.arr.shift
